@@ -2,7 +2,7 @@
 ####**********************************************************************
 ####
 ####  BOOSTED MULTIVARIATE TREES FOR LONGITUDINAL DATA (BOOSTMTREE)
-####  Version 1.1.0 (_PROJECT_BUILD_ID_)
+####  Version 1.2.0 (_PROJECT_BUILD_ID_)
 ####
 ####  Copyright 2016, University of Miami
 ####
@@ -106,7 +106,7 @@ blup.solve <- function(transf.data, membership, sigma, Kmax) {
     return(list(fix.eff = fix.eff, rnd.eff = rnd.eff))
   })
 }
-gls.mse  <- function(f, dta, trn, type = c("corCompSym", "corAR1", "corSymm", "iid")) {
+gls.rmse  <- function(f, dta, trn, type = c("corCompSym", "corAR1", "corSymm", "iid")) {
   f <- as.formula(f)
   type <- match.arg(type, c("corCompSym", "corAR1", "corSymm", "iid"))
     gls.grow <- tryCatch({
@@ -127,7 +127,11 @@ gls.mse  <- function(f, dta, trn, type = c("corCompSym", "corAR1", "corSymm", "i
     gls.pred  <- tapply(model.matrix(f, dta[-trn,]) %*% gls.grow$coef,
                         dta[-trn, "id"], function(x) {x})
     y.test <- tapply(dta[-trn, "y"], dta[-trn, "id"], function(x) {x})
-    l2Dist(gls.pred, y.test)
+    ysd <- sd(dta[trn, "y"], na.rm = TRUE)
+    if (ysd < 1e-6) {
+      ysd <- 1
+    }
+    l2Dist(gls.pred, y.test) / ysd
   }
   else {
     NA
@@ -175,7 +179,7 @@ is.hidden.partial <-  function (user.option) {
 }
 is.hidden.rho <-  function (user.option) {
   if (is.null(user.option$rho)) {
-    TRUE
+    NULL
   }
   else {
     user.option$rho
